Struct cgroups_rs::blkio::IoStat
source · pub struct IoStat {
pub major: i16,
pub minor: i16,
pub rbytes: u64,
pub wbytes: u64,
pub rios: u64,
pub wios: u64,
pub dbytes: u64,
pub dios: u64,
}Expand description
Per-device activity from the control group. Only for cgroup v2
Fields
major: i16The major number of the device.
minor: i16The minor number of the device.
rbytes: u64How many bytes were read from the device.
wbytes: u64How many bytes were written to the device.
rios: u64How many iops were read from the device.
wios: u64How many iops were written to the device.
dbytes: u64How many discard bytes were read from the device.
dios: u64How many discard iops were written to the device.