pub struct CgroupBuilder { /* private fields */ }
A control group builder instance

Implementations

Start building a control group with the supplied hierarchy and name pair.

Note that this does not actually create the control group until build() is called.

Builds the memory resources of the control group.

Builds the pid resources of the control group.

Builds the cpu resources of the control group.

Builds the devices resources of the control group, disallowing or allowing access to certain devices in the system.

Builds the network resources of the control group, setting class id, or various priorities on networking interfaces.

Builds the hugepage/hugetlb resources available to the control group.

Builds the block I/O resources available for the control group.

Finalize the control group, consuming the builder and creating the control group.

Specifically enable some controllers in the control group.