Struct cgroups_rs::cgroup_builder::CpuResourceBuilder
source · pub struct CpuResourceBuilder { /* private fields */ }Expand description
A builder that configures the cpuset & cpu controllers of a control group.
Implementations
sourceimpl CpuResourceBuilder
impl CpuResourceBuilder
sourcepub fn cpus(self, cpus: String) -> Self
pub fn cpus(self, cpus: String) -> Self
See the similarly named function in the respective controller.
sourcepub fn mems(self, mems: String) -> Self
pub fn mems(self, mems: String) -> Self
See the similarly named function in the respective controller.
See the similarly named function in the respective controller.
sourcepub fn quota(self, quota: i64) -> Self
pub fn quota(self, quota: i64) -> Self
See the similarly named function in the respective controller.
sourcepub fn period(self, period: u64) -> Self
pub fn period(self, period: u64) -> Self
See the similarly named function in the respective controller.
sourcepub fn realtime_runtime(self, realtime_runtime: i64) -> Self
pub fn realtime_runtime(self, realtime_runtime: i64) -> Self
See the similarly named function in the respective controller.
sourcepub fn realtime_period(self, realtime_period: u64) -> Self
pub fn realtime_period(self, realtime_period: u64) -> Self
See the similarly named function in the respective controller.
sourcepub fn done(self) -> CgroupBuilder
pub fn done(self) -> CgroupBuilder
Finish the construction of the cpu resources of a control group.