pub struct DeviceResourceBuilder { /* private fields */ }
A builder that configures the devices controller of a control group.

Implementations

Restrict (or allow) a device to the tasks inside the control group.

Finish the construction of the devices resources of a control group.