pub struct NetworkResourceBuilder { /* private fields */ }
A builder that configures the net_cls & net_prio controllers of a control group.

Implementations

See the similarly named function in the respective controller.

Set the priority of the tasks when operating on a networking device defined by name to be priority.

Finish the construction of the network resources of a control group.