Struct cgroups_rs::cgroup_builder::PidResourceBuilder
source · pub struct PidResourceBuilder { /* private fields */ }Expand description
A builder that configures the pid controller of a control group.
Implementations
sourceimpl PidResourceBuilder
impl PidResourceBuilder
sourcepub fn maximum_number_of_processes(
self,
maximum_number_of_processes: MaxValue
) -> Self
pub fn maximum_number_of_processes( self, maximum_number_of_processes: MaxValue ) -> Self
See the similarly named function in the respective controller.
sourcepub fn done(self) -> CgroupBuilder
pub fn done(self) -> CgroupBuilder
Finish the construction of the pid resources of a control group.