Struct cgroups_rs::cpuacct::CpuAcct
source · pub struct CpuAcct {
pub stat: String,
pub usage: u64,
pub usage_all: String,
pub usage_percpu: String,
pub usage_percpu_sys: String,
pub usage_percpu_user: String,
pub usage_sys: u64,
pub usage_user: u64,
}Expand description
Represents the statistics retrieved from the control group.
Fields
stat: StringDivides the time used by the tasks into user time and system time.
usage: u64Total CPU time (in nanoseconds) spent by the tasks.
usage_all: StringTotal CPU time (in nanoseconds) spent by the tasks, broken down by CPU and by whether the
time spent is user time or system time.
An example is as follows:
cpu user system
0 8348363768 0
1 8324369100 0
2 8598185449 0
3 8648262473 0
usage_percpu: StringCPU time (in nanoseconds) spent by the tasks, broken down by each CPU. Times spent in each CPU are separated by a space.
usage_percpu_sys: StringAs for usage_percpu, but the system time spent.
usage_percpu_user: StringAs for usage_percpu, but the user time spent.
usage_sys: u64CPU time (in nanoseconds) spent by the tasks that counted for system time.
usage_user: u64CPU time (in nanoseconds) spent by the tasks that counted for user time.