Module cgroups_rs::devices
source · Expand description
This module contains the implementation of the devices cgroup subsystem.
See the Kernel’s documentation for more information about this subsystem, found at: Documentation/cgroup-v1/devices.txt
Structs
A controller that allows controlling the
devices subsystem of a Cgroup.Enums
An enum with the permissions that can be allowed/denied to the control group.
An enum holding the different types of devices that can be manipulated using this controller.