ErrorKind

Enum ErrorKind 

pub enum ErrorKind {
Show 14 variants FsError, Common(String), WriteFailed(String, String), ReadFailed(String), RemoveFailed, ParseError, InvalidOperation, InvalidPath, InvalidBytesSize, SpecifiedControllers, CgroupVersion, CgroupMode, SubsystemsEmpty, Other,
}
The different types of errors that can occur while manipulating control groups.

Variants



FsError



Common(String)



WriteFailed(String, String)

An error occured while writing to a control group file.



ReadFailed(String)

An error occured while trying to read from a control group file.



RemoveFailed

An error occured while trying to remove a control group.



ParseError

An error occured while trying to parse a value from a control group file.

In the future, there will be some information attached to this field.



InvalidOperation

You tried to do something invalid.

This could be because you tried to set a value in a control group that is not a root control group. Or, when using unified hierarchy, you tried to add a task in a leaf node.



InvalidPath

The path of the control group was invalid.

This could be caused by trying to escape the control group filesystem via a string of “..”. This crate checks against this and operations will fail with this error.



InvalidBytesSize



SpecifiedControllers

The specified controller is not in the list of supported controllers.



CgroupVersion

Using method in wrong cgroup version.



CgroupMode

Using method in wrong cgroup mode.



SubsystemsEmpty

Subsystems is empty.



Other

An unknown error has occured.