NumaStat

Struct NumaStat 

pub struct NumaStat {
Show 16 fields pub total_pages: u64, pub total_pages_per_node: Vec<u64>, pub file_pages: u64, pub file_pages_per_node: Vec<u64>, pub anon_pages: u64, pub anon_pages_per_node: Vec<u64>, pub unevictable_pages: u64, pub unevictable_pages_per_node: Vec<u64>, pub hierarchical_total_pages: u64, pub hierarchical_total_pages_per_node: Vec<u64>, pub hierarchical_file_pages: u64, pub hierarchical_file_pages_per_node: Vec<u64>, pub hierarchical_anon_pages: u64, pub hierarchical_anon_pages_per_node: Vec<u64>, pub hierarchical_unevictable_pages: u64, pub hierarchical_unevictable_pages_per_node: Vec<u64>,
}
Contains statistics about the NUMA locality of the control group’s tasks.

Fields

total_pages: u64

Total amount of pages used by the control group.

total_pages_per_node: Vec<u64>

Total amount of pages used by the control group, broken down by NUMA node.

file_pages: u64

Total amount of file pages used by the control group.

file_pages_per_node: Vec<u64>

Total amount of file pages used by the control group, broken down by NUMA node.

anon_pages: u64

Total amount of anonymous pages used by the control group.

anon_pages_per_node: Vec<u64>

Total amount of anonymous pages used by the control group, broken down by NUMA node.

unevictable_pages: u64

Total amount of unevictable pages used by the control group.

unevictable_pages_per_node: Vec<u64>

Total amount of unevictable pages used by the control group, broken down by NUMA node.

hierarchical_total_pages: u64

Same as total_pages, but includes the descedant control groups’ number as well.

hierarchical_total_pages_per_node: Vec<u64>

Same as total_pages_per_node, but includes the descedant control groups’ number as well.

hierarchical_file_pages: u64

Same as file_pages, but includes the descedant control groups’ number as well.

hierarchical_file_pages_per_node: Vec<u64>

Same as file_pages_per_node, but includes the descedant control groups’ number as well.

hierarchical_anon_pages: u64

Same as anon_pages, but includes the descedant control groups’ number as well.

hierarchical_anon_pages_per_node: Vec<u64>

Same as anon_pages_per_node, but includes the descedant control groups’ number as well.

hierarchical_unevictable_pages: u64

Same as unevictable, but includes the descedant control groups’ number as well.

hierarchical_unevictable_pages_per_node: Vec<u64>

Same as unevictable_per_node, but includes the descedant control groups’ number as well.