DeviceResource

Struct DeviceResource 

pub struct DeviceResource {
    pub allow: bool,
    pub devtype: DeviceType,
    pub major: i64,
    pub minor: i64,
    pub access: Vec<DevicePermissions>,
}
A device resource that can be allowed or denied access to.

Fields

allow: bool

If true, access to the device is allowed, otherwise it’s denied.

devtype: DeviceType

'c' for character device, 'b' for block device; or 'a' for all devices.

major: i64

The major number of the device.

minor: i64

The minor number of the device.

access: Vec<DevicePermissions>

Sequence of 'r', 'w' or 'm', each denoting read, write or mknod permissions.