Struct cgroups_rs::memory::Tcp
source · pub struct Tcp {
pub fail_cnt: u64,
pub limit_in_bytes: i64,
pub usage_in_bytes: u64,
pub max_usage_in_bytes: u64,
}Expand description
The current state of and gathered statistics about the kernel’s memory usage for TCP-related data structures.
Fields
fail_cnt: u64How many times the limit has been hit.
limit_in_bytes: i64The limit in bytes of the memory usage of the kernel’s TCP buffers by control group’s tasks.
usage_in_bytes: u64The current memory used by the kernel’s TCP buffers related to these tasks.
max_usage_in_bytes: u64The observed maximum usage of memory by the kernel’s TCP buffers (that originated from these tasks).