pub enum DevicePermissions {
    Read,
    Write,
    MkNod,
}
An enum with the permissions that can be allowed/denied to the control group.

Variants



Read

Permission to read from the device.



Write

Permission to write to the device.



MkNod

Permission to execute the mknod(2) system call with the device’s major and minor numbers. That is, the permission to create a special file that refers to the device node.

Implementations

Convert a DevicePermissions into the character that the kernel recognizes.

Convert a char to a DevicePermission if there is such a mapping.

Checks whether the string is a valid descriptor of DevicePermissions.

Returns a Vec will all the permissions that a device can have.

Convert a string into DevicePermissions.