Struct cgroups_rs::memory::MemSwap

source ·
pub struct MemSwap {
    pub fail_cnt: u64,
    pub limit_in_bytes: i64,
    pub usage_in_bytes: u64,
    pub max_usage_in_bytes: u64,
}
Contains statistics about the current usage of memory and swap (together, not seperately) by the control group’s tasks.

Fields

fail_cnt: u64

How many times the limit has been hit.

limit_in_bytes: i64

Memory and swap usage limit in bytes.

usage_in_bytes: u64

Current usage of memory and swap in bytes.

max_usage_in_bytes: u64

The maximum observed usage of memory and swap in bytes.